## 沪深京实时日线

接口：rt_k

描述：获取实时日k线行情，支持按股票代码及股票代码通配符一次性提取全部股票实时日k线行情

限量：单次最大可提取6000条数据

积分：本接口是单独开权限的数据，单独申请权限请参考权限列表

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 支持通配符方式，e.g. 6*.SH、301*.SZ、600000.SH |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| name | None | Y | 股票名称 |
| pre_close | float | Y | 昨收价 |
| high | float | Y | 最高价 |
| open | float | Y | 开盘价 |
| low | float | Y | 最低价 |
| close | float | Y | 收盘价（最新价） |
| vol | int | Y | 成交量（股） |
| amount | int | Y | 成交金额（元） |
| num | int | Y | 开盘以来成交笔数 |
| ask_volume1 | int | N | 委托卖盘（股） |
| bid_volume1 | int | N | 委托买盘（股） |

接口示例

```python
#获取今日开盘以来所有创业板实时日线和成交笔数
df = pro.rt_k(ts_code='3*.SZ')

#获取今日开盘以来全市场所有股票实时日线和成交笔数
df = pro.rt_k(ts_code='3*.SZ,6*.SH,0*.SZ,9*.BJ')

#获取当日开盘以来单个股票实时日线和成交笔数
df = pro.rt_k(ts_code='600000.SH,000001.SZ')
```

数据示例

```python
ts_code  name      pre_close   high   open   low  close     vol      amount     num
0    601866.SH  中远海发       2.28   2.28   2.28   2.23   2.24  55845293  125364882  19904
```